From: Tom Lendacky <thomas.lenda...@amd.com>

The current code checks only for sme_active() when determining whether
to perform the encryption attribute change.  Include sev_active() in this
check so that memory attribute changes can occur under SME and SEV.

Signed-off-by: Tom Lendacky <thomas.lenda...@amd.com>
Signed-off-by: Brijesh Singh <brijesh.si...@amd.com>
---
 arch/x86/mm/pageattr.c | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/arch/x86/mm/pageattr.c b/arch/x86/mm/pageattr.c
index dfb7d65..b726b23 100644
--- a/arch/x86/mm/pageattr.c
+++ b/arch/x86/mm/pageattr.c
@@ -1781,8 +1781,8 @@ static int __set_memory_enc_dec(unsigned long addr, int 
numpages, bool enc)
        unsigned long start;
        int ret;
 
-       /* Nothing to do if the SME is not active */
-       if (!sme_active())
+       /* Nothing to do if SME and SEV are not active */
+       if (!sme_active() && !sev_active())
                return 0;
 
        /* Should not be working on unaligned addresses */
-- 
2.9.4

Reply via email to